# athigeo


[![image](https://img.shields.io/pypi/v/athigeo.svg)](https://pypi.python.org/pypi/athigeo)
[![image](https://img.shields.io/conda/vn/conda-forge/athigeo.svg)](https://anaconda.org/conda-forge/athigeo)


**A python package intro**


-   Free software: MIT License
-   Documentation: https://athigeo.xyz/
    

## Features

-   visualize raster and vector data

- Analyzing raster and vector data
- Print out useful Message
